# variables
# (1) subject : Subject number for 43 non-schizophrenic and 43 schizophrenic subjects
# (2) sch     : Indicator of schizophrenic subjects (=1) or not (=0)
# (3) sex     : Gender of subjects (1=male, 0=female)
# (4) x1      : Effect of PS versus CS (-0.5=CS, 0.5=PS, 0=TR)
# (5) x2      : Effect of TR versus CS and PS (-1/3=CS, -1/3=PS, 2/3=TR)
# (6) time    : Linear trend coded -5, ..., 5 for 11 measurement times of each subject.
# (7) y       : Gain Raitos for the each measurements of the subject

#### GLM ###
model_mu<-DHGLMMODELING(Model="mean", Link="identity", LinPred=y~x1+x2+time+sch+sch*x1+sch*x2)
model_phi<-DHGLMMODELING(Model="dispersion")
res_glm<-dhglmfit(RespDist="gaussian",DataMain=data_sch,MeanModel=model_mu,DispersionModel=model_phi)

#### JGLM ###
model_mu<-DHGLMMODELING(Model="mean", Link="identity", LinPred=y~x1+x2+time+sch+sch*x1+sch*x2)
model_phi<-DHGLMMODELING(Model="dispersion",Link="log", LinPred=phi~sch)
res_jglm<-dhglmfit(RespDist="gaussian",DataMain=data_sch,MeanModel=model_mu,DispersionModel=model_phi)

#### HGLM ###
model_mu<-DHGLMMODELING(Model="mean", Link="identity", LinPred=y~x1+x2+time+sch+sch*x1+sch*x2+(1|subject),RandDist="gaussian")
model_phi<-DHGLMMODELING(Model="dispersion",Link="log", LinPred=phi~sch)
res_hglm<-dhglmfit(RespDist="gaussian",DataMain=data_sch,MeanModel=model_mu,DispersionModel=model_phi)

#### DHGLM I ###
model_mu<-DHGLMMODELING(Model="mean", Link="identity", LinPred=y~x1+x2+time+sch+sch*x1+sch*x2+(1|subject),RandDist="gaussian")
model_phi<-DHGLMMODELING(Model="dispersion",Link="log", LinPred=phi~sch+(sch|subject),RandDist="gaussian")
res_dhglm1<-dhglmfit(RespDist="gaussian",DataMain=data_sch,MeanModel=model_mu,DispersionModel=model_phi)

#### DHGLM II ###
model_mu<-DHGLMMODELING(Model="mean", Link="identity", LinPred=y~x1+x2+time+sch+sch*x1+sch*x2+(1|subject),RandDist="gaussian",
         LinkRandVariance="log",LinPredRandVariance=lambda~1+(1|subject))
model_phi<-DHGLMMODELING(Model="dispersion", Link="log", LinPred=phi~sch,RandDist="gaussian")
res_dhglm2<-dhglmfit(RespDist="gaussian",DataMain=data_sch,MeanModel=model_mu,DispersionModel=model_phi)

#### DHGLM III ###
model_mu<-DHGLMMODELING(Model="mean", Link="identity", LinPred=y~x1+x2+time+sch+sch*x1+sch*x2+(1|subject),RandDist="gaussian",
         LinkRandVariance="log",LinPredRandVariance=lambda~1+(1|subject))
model_phi<-DHGLMMODELING(Model="dispersion", Link="log", LinPred=phi~sch+(sch|subject),RandDist="gaussian")
res_dhglm3<-dhglmfit(RespDist="gaussian",DataMain=data_sch,MeanModel=model_mu,DispersionModel=model_phi)


plotdhglm(res_hglm)
plotdhglm(res_dhglm1)
plotdhglm(res_dhglm2)
plotdhglm(res_dhglm3)

